==> haskell-tasty-smallcheck-0.8.2-498-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-HYnM2nw1KHpC69eEgsoLAY
key:                  tasty-smallcheck-0.8.2-HYnM2nw1KHpC69eEgsoLAY
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  04ef7fb554f7cf324877e0f7ff841be2
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-HYnM2nw1KHpC69eEgsoLAY
depends:
    base-4.16.4.0 optparse-applicative-0.17.1.0-92ShIE9pEy5K3fr8qppb26
    smallcheck-1.2.1.1-HRM8jhFcf9RIs5hW36JuIf
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP
    tasty-1.4.3-7mwiS20bCN4I3SJ3l4eJAB

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-smallcheck-0.8.2-501-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-8tKqoeN3FjUHtvhSkXpHwk
key:                  tasty-smallcheck-0.8.2-8tKqoeN3FjUHtvhSkXpHwk
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  d24b94c1cc711cd83ac736dc4e8f0022
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-8tKqoeN3FjUHtvhSkXpHwk
depends:
    base-4.16.4.0 optparse-applicative-0.17.1.0-FEdHU4ERawH5ZWhC4bBeG0
    smallcheck-1.2.1.1-6F8UzwZpA7wLVqtYaLl2X2
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP
    tasty-1.4.3-HG1lp3DnHkK33QKXUVI3A7

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
